==> dtkdeclarative-debug-5.6.34-1.1-x86_64.pkg.tar.zst: usr/src/debug/dtkdeclarative/dtkdeclarative/src/qml_WarningButton_qml.cpp <==
// /dtk/declarative/qml/WarningButton.qml
namespace QmlCacheGeneratedCode {
namespace _dtk_declarative_qml_WarningButton_qml {
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x29,0x0,0x0,0x0,0xf,0xf,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xcc,0x4,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x87,0x4,0x6f,0x51,
0x49,0x96,0xed,0x8c,0x4a,0x44,0x64,0x1,
0xf8,0xd3,0x67,0x6f,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x4,0x0,0x0,
0x10,0x1,0x0,0x0,0x43,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0xb0,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x2e,0x0,0x3a,0x1,0x3a,0x2,0x3a,0x3,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x98,0x1,0x0,0x0,0xb8,0x1,0x0,0x0,
0xe0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x40,0x2,0x0,0x0,0x60,0x2,0x0,0x0,
0xa8,0x2,0x0,0x0,0xd0,0x2,0x0,0x0,
0xf8,0x2,0x0,0x0,0x28,0x3,0x0,0x0,
0x78,0x3,0x0,0x0,0xa0,0x3,0x0,0x0,
0xd8,0x3,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x51,0x0,0x74,0x0,0x51,0x0,0x75,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x13,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x72,0x0,0x67,0x0,0x2e,0x0,
0x64,0x0,0x65,0x0,0x65,0x0,0x70,0x0,
0x69,0x0,0x6e,0x0,0x2e,0x0,0x64,0x0,
0x74,0x0,0x6b,0x0,0x2e,0x0,0x69,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x53,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x14,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x72,0x0,0x67,0x0,0x2e,0x0,
0x64,0x0,0x65,0x0,0x65,0x0,0x70,0x0,
0x69,0x0,0x6e,0x0,0x2e,0x0,0x64,0x0,
0x74,0x0,0x6b,0x0,0x2e,0x0,0x73,0x0,
0x74,0x0,0x79,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x42,0x0,0x75,0x0,0x74,0x0,0x74,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,
0x72,0x0,0x6f,0x0,0x6c,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x18,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x65,0x0,0x78,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x73,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x20,0x0,0x66,0x0,
0x6f,0x0,0x72,0x0,0x20,0x0,0x74,0x0,
0x65,0x0,0x78,0x0,0x74,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x53,0x0,0x74,0x0,0x79,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x77,0x0,0x61,0x0,0x72,0x0,0x6e,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x42,0x0,
0x75,0x0,0x74,0x0,0x74,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0x1,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0x5c,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x9,0x0,0x10,0x0,0xa,0x0,0x50,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0xb,0x0,0x0,0x1,
0x0,0x0,0x0,0x0
};
}
}

==> dtkdeclarative-debug-5.7.11-1-x86_64.pkg.tar.zst: usr/src/debug/dtkdeclarative/dtkdeclarative/src/qml_WarningButton_qml.cpp <==
// /dtk/declarative/qml/WarningButton.qml
namespace QmlCacheGeneratedCode {
namespace _dtk_declarative_qml_WarningButton_qml {
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x29,0x0,0x0,0x0,0x10,0xf,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xcc,0x4,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x87,0x4,0x6f,0x51,
0x49,0x96,0xed,0x8c,0x4a,0x44,0x64,0x1,
0xf8,0xd3,0x67,0x6f,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x4,0x0,0x0,
0x10,0x1,0x0,0x0,0x43,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0xb0,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x2e,0x0,0x3a,0x1,0x3a,0x2,0x3a,0x3,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x98,0x1,0x0,0x0,0xb8,0x1,0x0,0x0,
0xe0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x40,0x2,0x0,0x0,0x60,0x2,0x0,0x0,
0xa8,0x2,0x0,0x0,0xd0,0x2,0x0,0x0,
0xf8,0x2,0x0,0x0,0x28,0x3,0x0,0x0,
0x78,0x3,0x0,0x0,0xa0,0x3,0x0,0x0,
0xd8,0x3,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x51,0x0,0x74,0x0,0x51,0x0,0x75,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x13,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x72,0x0,0x67,0x0,0x2e,0x0,
0x64,0x0,0x65,0x0,0x65,0x0,0x70,0x0,
0x69,0x0,0x6e,0x0,0x2e,0x0,0x64,0x0,
0x74,0x0,0x6b,0x0,0x2e,0x0,0x69,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x53,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x14,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x72,0x0,0x67,0x0,0x2e,0x0,
0x64,0x0,0x65,0x0,0x65,0x0,0x70,0x0,
0x69,0x0,0x6e,0x0,0x2e,0x0,0x64,0x0,
0x74,0x0,0x6b,0x0,0x2e,0x0,0x73,0x0,
0x74,0x0,0x79,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x42,0x0,0x75,0x0,0x74,0x0,0x74,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,
0x72,0x0,0x6f,0x0,0x6c,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x18,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x65,0x0,0x78,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x73,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x20,0x0,0x66,0x0,
0x6f,0x0,0x72,0x0,0x20,0x0,0x74,0x0,
0x65,0x0,0x78,0x0,0x74,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x53,0x0,0x74,0x0,0x79,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x77,0x0,0x61,0x0,0x72,0x0,0x6e,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x42,0x0,
0x75,0x0,0x74,0x0,0x74,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0x1,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0x5c,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x9,0x0,0x10,0x0,0xa,0x0,0x50,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0xb,0x0,0x0,0x1,
0x0,0x0,0x0,0x0
};
}
}
